#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_LDEXP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_LDEXP_HPP_INCLUDED

#include <nt2/ieee/include/functions/scalar/fast_ldexp.hpp>

#endif
